@@ -40,9 +40,6 @@ int dansguardian_log()
    int  idata=0;
    int  x, y;
 
-   if(strlen(DansGuardianConf) < 1)
-     return;
-
    bzero(day, 3);
    bzero(mon, 4);
    bzero(year, 5);
@@ -137,17 +134,29 @@ int dansguardian_log()
       sprintf(wdata,"%s%02d%s",year,atoi(mon),day);
       idata = atoi(wdata);
 
-      if(idata >= dfrom && idata <= duntil) {
-         if(strcmp(user,"-") == 0)
-            strcpy(user,ip);
-         sprintf(tmp6,"%s %d %s %s %s %s %s\n",user,idata,hour,ip,url,code1,code2);
-         fputs(tmp6, fp_ou);
-         dansguardian_count++;
+      if(strcmp(DansguardianIgnoreDate,"on") == 0) {
+         if(idata < dfrom && idata > duntil)
+            continue;
       }
+
+      if (strcmp(user,"-") == 0) {
+         strcpy(user,ip);
+         bzero(ip, 30);
+      }
+      sprintf(tmp6,"%s %d %s %s %s %s %s\n",user,idata,hour,ip,url,code1,code2);
+      fputs(tmp6, fp_ou);
+      dansguardian_count++;
    }
-   fclose(fp_in);
-   fclose(fp_guard);
-   fclose(fp_ou);
+
+   if(fp_in) fclose(fp_in);
+   if(fp_guard) fclose(fp_guard);
+   if(fp_ou) fclose(fp_ou);
+
+   if(debug) {
+      sprintf(msg,"%s: %s",text[54],guard_ou);
+      debuga(msg);
+   }
+
    sprintf(tmp6,"sort -k 1,1 -k 2,2 -k 4,4 '%s' -o '%s'",guard_in, guard_ou);
    system(tmp6);
    unlink(guard_in);
