@@ -105,7 +105,10 @@ void dansguardian_report()
       fputs("</table>\n",fp_ou);
    }
 
-   show_sarg(fp_ou,"..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_ou, "../../..");
+   else
+      show_sarg(fp_ou,"..");
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
    sprintf(url,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(url,fp_ou);
@@ -200,7 +203,7 @@ void dansguardian_report()
             continue;
       }
 
-      sprintf(html2,"<tr><td class=\"data2\">%s</td><td class=\"data2\">%s</td><td class=\"data2\">%s-%s</td><td class=\"data2\"><a href=\"http://%s\">%s</a></td><td class=\"data2\">%s</td></tr>\n",name,ip,date,hour,url,url,rule);
+      sprintf(html2,"<tr><td class=\"data2\" nospaw>%s</td><td class=\"data2\" nospaw>%s</td><td class=\"data2\" nospaw>%s-%s</td><td class=\"data2\" nospaw><a href=\"http://%s\">%s</a></td><td class=\"data2\" nospaw>%s</td></tr>\n",name,ip,date,hour,url,url,rule);
       fputs(html2,fp_ou);
    }
 
