@@ -52,7 +52,7 @@ void gen_denied_report()
 
    ouser[0]='\0';
 
-   sprintf(denied_in,"%s/denied.log",TempDir);
+   sprintf(denied_in,"%s/sarg/denied.log",TempDir);
    if(!denied_count) {
       unlink(denied_in);
       return;
@@ -101,7 +101,10 @@ void gen_denied_report()
       fputs("</table>\n",fp_ou);
    }
 
-   show_sarg(fp_ou, "..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_ou, "../../..");
+   else
+      show_sarg(fp_ou, "..");
    sprintf(url,"<tr><th class=\"title\">%s</b></th></tr>\n",Title);
    fputs(url,fp_ou);
 
@@ -179,7 +182,7 @@ void gen_denied_report()
       }
 
       if(strlen(BlockIt) > 0)
-         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"../images/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url);
+         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"%s/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url,ImageFile);
       else BlockImage[0]='\0';
 
       sprintf(html2,"<tr><td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s-%s</td><td class=\"data2\">%s<a href=\"%s\">%s</a></td></th>\n",name,ip,data,hora,BlockImage,url,url);
