@@ -99,7 +99,10 @@ void download_report()
       fputs("</table>\n",fp_ou);
    }
 
-   show_sarg(fp_ou, "..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_ou, "../../..");
+   else
+      show_sarg(fp_ou, "..");
    sprintf(url,"<tr><th class=\"title\">%s</b></th></tr>\n",Title);
    fputs(url,fp_ou);
 
@@ -177,7 +180,7 @@ void download_report()
       }
 
       if(strlen(BlockIt) > 0)
-         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"../images/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url);
+         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"%s/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url,ImageFile);
       else BlockImage[0]='\0';
 
       sprintf(html2,"<tr><td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s-%s</td><td class=\"data2\">%s<a href=\"%s\">%s</a></td></th>\n",name,ip,data,hora,BlockImage,url,url);
