@@ -52,7 +52,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    strcat(top1,"/top");
    strcat(top2,"/top.tmp");
    strcat(top3,"/report");
-   strcat(tusr,"/usuarios");
+   strcat(tusr,"/users");
 
    if((fp_in=fopen(wger,"r"))==NULL) {
       fprintf(stderr, "SARG: (email) %s: %s\n",text[45],wger);
