@@ -364,6 +364,13 @@ int parmtest(char *buf)
          return;
       }      
 
+      if(strstr(buf,"index_tree") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(IndexTree,buf);
+         fixnone(IndexTree);
+         return;
+      }      
+
       if(strstr(buf,"index") != 0) {
          if(strstr(buf,"index_sort_order") == 0) {
             getword(wbuf,buf,' ');
@@ -586,6 +593,13 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"datafile_url") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(DataFileUrl,buf);
+         fixnone(DataFileUrl);
+         return;
+      }
+
       if(strstr(buf,"parsed_output_log") != 0) {
 	 if(strstr(buf,"parsed_output_log_compress") == 0) {
             getword(wbuf,buf,' ');
@@ -735,6 +749,20 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"squidguard_ignore_date") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(SquidguardIgnoreDate,buf);
+         fixnone(SquidguardIgnoreDate);
+         return;
+      }
+
+      if(strstr(buf,"dansguardian_ignore_date") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(DansguardianIgnoreDate,buf);
+         fixnone(DansguardianIgnoreDate);
+         return;
+      }
+
       if(strstr(buf,"ulimit") != 0) {
          getword(wbuf,buf,' ');
          strcpy(Ulimit,buf);
@@ -748,6 +776,40 @@ int parmtest(char *buf)
          fixnone(NtlmUserFormat);
          return;
       }
+
+      if(strstr(buf,"realtime_types") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(RealtimeTypes,buf);
+         fixnone(RealtimeTypes);
+         return;
+      }
+
+      if(strstr(buf,"realtime_unauthenticated_records") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(RealtimeUnauthRec,buf);
+         fixnone(RealtimeUnauthRec);
+         return;
+      }
+
+      if(strstr(buf,"realtime_refresh_time") != 0) {
+         getword(wbuf,buf,' ');
+         realtime_refresh=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"realtime_access_log_lines") != 0) {
+         getword(wbuf,buf,' ');
+         realtime_access_log_lines=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"byte_cost") != 0) {
+         getword(wbuf,buf,' ');
+         cost=atol(buf);
+         getword(wbuf,buf,' ');
+         nocost=my_atoll(buf);
+         return;
+      }
     
       return;
 }
