@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -321,6 +321,11 @@ void greport_day(char *user, int *iprel, int *ipuser)
    if(strcmp(DateFormat,"e") == 0)
       strftime(ftime, 127, "%d/%b/%Y-%H:%M", local);
 
+   if(dotinuser && strstr(name,"_")) {
+      str2=(char *)subs(name,"_",".");
+      strcpy(name,str2);
+   }
+
    SARGgdImageStringFT(im,&brect[0],darkblue,font1,7,0.0,620,470,ftime);
    if(strcmp(ShowSargInfo,"yes") == 0) SARGgdImageStringFT(im,&brect[0],darkblue,font1,10,0.0,257,15,"SARG, ");
    SARGgdImageStringFT(im,&brect[0],darkblue,font1,10,0.0,300,15,Title);
@@ -374,9 +379,9 @@ void greport_day(char *user, int *iprel, int *ipuser)
    if(access(wdirname, R_OK) != 0)
       return;
 
-   sprintf(csort,"sort -t'/' -k 2,2 -o %s %s",tmp5,wdirname);
+   sprintf(csort,"sort -t'/' -k 2,2 -o '%s' '%s'",tmp5,wdirname);
    if(strcmp(DateFormat,"e") == 0)
-      sprintf(csort,"sort -t'/' -k 1,1 -o %s %s",tmp5,wdirname);
+      sprintf(csort,"sort -t'/' -k 1,1 -o '%s' '%s'",tmp5,wdirname);
 
    system(csort);
 
