@@ -35,7 +35,7 @@ void htmlrel()
    long long int totelap=0, totelap2=0, nnelap=0, unelap=0, tnelap=0;
    long long int incache=0, oucache=0, tnincache=0, tnoucache=0, twork=0, twork2=0;
    char arqin[MAXLEN], arqou[MAXLEN], arqper[MAXLEN], arqip[MAXLEN];
-   char nacc[20], nbytes[20], url[1024], purl[1024], tmsg[30], tmsg2[30], nelap[20], csort[MAXLEN];
+   char nacc[20], nbytes[20], url[1024], purl[1024], tmsg[50], tmsg2[50], nelap[20], csort[MAXLEN];
    char periodo[MAXLEN], usuario[MAXLEN], wusuario[MAXLEN], u2[MAXLEN], duser[MAXLEN];
    char userbytes[20], userelap[20], userurl[1024], userhora[9], userdia[9];
    char user_ip[MAXLEN], olduserip[MAXLEN], tmp2[MAXLEN], tmp3[MAXLEN], incac[20], oucac[20];
@@ -195,7 +195,11 @@ void htmlrel()
       fputs("</table>\n",fp_ou);
    }
 
-      show_sarg(fp_ou,"../..");
+      if(strcmp(IndexTree,"date") == 0)
+         show_sarg(fp_ou, "../../../..");
+      else
+         show_sarg(fp_ou, "../..");
+
       fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
       sprintf(html,"<tr><th class=\"title\" colspan=\"2\">%s</th></tr>\n",Title);
       fputs(html,fp_ou);
@@ -348,8 +352,11 @@ void htmlrel()
             sprintf(httplink,"<font color=%s><href=http://%s>%s",       \
                     PrivacyStringColor,PrivacyString,PrivacyString);
           else
+             strcpy(tmp6,"../../images");
+             if(strcmp(IndexTree,"date") == 0)
+                sprintf(tmp6,"../%s",ImageFile);
              if(strlen(BlockIt) > 0)
-                sprintf(httplink,"<a href=\"%s%s?url=%s\"><img src=\"../../images/sarg-squidguard-block.png\" border=\"0\"></a><a href=http://%s>&nbsp;%s</a>",wwwDocumentRoot,BlockIt,urly,urly,urly);
+                sprintf(httplink,"<a href=\"%s%s?url=%s\"><img src=\"%s/sarg-squidguard-block.png\" border=\"0\"></a><a href=http://%s>&nbsp;%s</a>",wwwDocumentRoot,BlockIt,urly,tmp6,urly,urly);
              else
                 sprintf(httplink,"<a href=http://%s title=\"%s\">%s</a>",urly,urly,url);
 
@@ -365,7 +372,7 @@ void htmlrel()
 	       if(str[z1]=='?' || str[z1]=='-' || str[z1]=='.' || str[z1]==':' || str[z1]=='/' || str[z1]=='\\')
                   str[z1]='_';
             }
-            sprintf(href2,"<a href=\"tt%s-%s.html\"><img src=\"../../images/datetime.png\" border=\"0\" title=\"%s %s\"></a>",usuario,siteind,ltext110,text[55]);
+            sprintf(href2,"<a href=\"tt%s-%s.html\"><img src=\"%s/datetime.png\" border=\"0\" title=\"%s %s\"></a>",usuario,siteind,tmp6,ltext110,text[55]);
          } else {
             bzero(href2, MAXLEN);
             bzero(ltext110, 50);
@@ -605,10 +612,10 @@ void htmlrel()
                   fprintf(stderr, "SARG: (html9) %s: %s\n",text[45],PerUserLimitFile);
                   exit(1);
                }
-               while(fgets(tmp5,sizeof(tmp5),fp_usr)!=NULL) {
-                  if(strstr(tmp5,"\n") != 0)
-                     tmp5[strlen(tmp5)-1]='\0';
-                  if(strcmp(tmp5,u2) == 0) {
+               while(fgets(tmp6,sizeof(tmp6),fp_usr)!=NULL) {
+                  if(strstr(tmp6,"\n") != 0)
+                     tmp6[strlen(tmp6)-1]='\0';
+                  if(strcmp(tmp6,u2) == 0) {
                      limit_flag=1;
                      break;
                   }
@@ -634,8 +641,8 @@ void htmlrel()
       }
 
       strcpy(arqper,dirname);
-      strcat(arqper,"/usuarios");
-   
+      strcat(arqper,"/users");
+ 
       if ((fp_in = fopen(arqper, "r")) == 0){
          fprintf(stderr, "SARG: (html11) %s: %s\n",text[45],arqper);
          exit(1);
@@ -714,7 +721,7 @@ void htmlrel()
 
       fclose(fp_ou);
 
-      htaccess(name);
+      htaccess(wusuario);
 
    }
 
