@@ -114,29 +114,33 @@ char href[MAXLEN];
 char href2[MAXLEN];
 char href3[MAXLEN];
 char df[20];
-char day[3], month[3], year[5];
+char day[3], month[4], year[5];
+char nmonth[30];
+char y1[5], y2[5];
+char d1[3], d2[3];
+char m1[4], m2[4];
 char ltext110[50];
 char cdfrom[30];
 char cduntil[30];
 char LastLog[5];
 char RemoveTempFiles[4];
 char ReplaceIndex[256];
-char Index[5];
+char Index[20];
 char OverwriteReport[4];
 char RecordsWithoutUser[20];
 char UseComma[4];
 char MailUtility[6];
-char TopSitesNum[5];
-char TopUsersNum[5];
+char TopSitesNum[20];
+char TopUsersNum[20];
 char ExcludeCodes[256];
 char TopsitesSortField[15];
-char TopsitesSortType[5];
+char TopsitesSortType[20];
 char ReportType[255];
 char UserTabFile[255];
 char warea[MAXLEN];
 char name[MAXLEN];
-char LongUrl[4];
-char Ip2Name[5];
+char LongUrl[20];
+char Ip2Name[20];
 char language[255];
 char AccessLog[MAXLEN];
 char Title[MAXLEN];
@@ -188,20 +192,24 @@ char UserReportFields[255];
 char DataFile[MAXLEN];
 char DataFileDelimiter[3];
 char DataFileFields[MAXLEN];
+char DataFileUrl[20];
 char SiteUserTimeDateType[10];
 char ShowReadStatistics[5];
 char IndexSortOrder[5];
 char DansGuardianConf[MAXLEN];
+char DansguardianIgnoreDate[10];
 char SquidGuardConf[MAXLEN];
 char SquidGuarddbHome[255];
 char SquidGuardLogFormat[MAXLEN];
+char SquidGuardLogAlternate[MAXLEN];
+char SquidguardIgnoreDate[10];
 char ShowSargInfo[5];
 char ShowSargLogo[5];
 char ParsedOutputLog[MAXLEN];
 char ParsedOutputLogCompress[255];
 char DisplayedValues[20];
-char HeaderFontSize[3];
-char TitleFontSize[3];
+char HeaderFontSize[4];
+char TitleFontSize[5];
 char wwwDocumentRoot[MAXLEN];
 char ExternalCSSFile[MAXLEN];
 char BlockIt[255];
@@ -217,6 +225,7 @@ char hbc7[30];
 char hbc8[30];
 char hbc9[30];
 char hbc10[30];
+char IndexTree[10];
 char UserAuthentication[10];
 char AuthUserFile[255];
 char AuthName[512];
@@ -257,8 +266,14 @@ char wentp[512];
 char addr[MAXLEN];
 char suffix[10];
 char download_url[MAXLEN];
-char Ulimit[5];
+char Ulimit[6];
+char RealtimeTypes[1024];
 char cmd[255];
+char ImageFile[255];
+char tbuf[128];
+char ip[25];
+char RealtimeUnauthRec[15];
+
 int  excode;
 int  idate;
 int  smartfilter;
@@ -295,11 +310,18 @@ int  SquidGuardReportLimit;
 int  UserReportLimit;
 int  download_flag;
 int  dotinuser;
+int  realtime_refresh;
+int  realtime_access_log_lines;
+int  realt;
+int  x, y;
+int  rc;
 long l1, l2;
 float perc;
 
 long long int twork;
 long long int twork2;
+long long int nocost;
+float cost;
 
 typedef struct
 { int list[ 24 ];
