@@ -59,9 +59,11 @@ void mklastlog()
       local = localtime(&t);
       strftime(ftime, 127, "%Y%m%d%H%M%S", local);
       sprintf(buf,"%s %s\n",ftime,direntp->d_name);
+printf("BUF=%s\n",buf);
       fputs(buf,fp_ou);
       ftot++;
    }
+exit(0);
 
    (void)rewinddir( dirp );
    (void)closedir( dirp );
