@@ -146,11 +146,12 @@ int main(argc,argv)
    BlockIt[0]='\0';
    ExternalCSSFile[0]='\0';
    SquidGuardLogFormat[0]='\0';
+   SquidGuardLogAlternate[0]='\0';
 
    strcpy(AccessLog,"/usr/local/squid/var/logs/access.log");
    sprintf(ExcludeCodes,"%s/exclude_codes",SYSCONFDIR);
    strcpy(GraphDaysBytesBarColor,"orange");
-   strcpy(BgColor,"#FFFFFF");
+   strcpy(BgColor,"#ffffff");
    strcpy(TxColor,"#000000");
    strcpy(TxBgColor,"lavender");
    strcpy(TiColor,"darkblue");
@@ -158,7 +159,7 @@ int main(argc,argv)
    strcpy(Height,"45");
    strcpy(LogoTextColor,"#000000");
    strcpy(HeaderColor,"darkblue");
-   strcpy(HeaderBgColor,"#DDDDDD");
+   strcpy(HeaderBgColor,"#dddddd");
    strcpy(LogoTextColor,"#006699");
    strcpy(FontSize,"9px");
    strcpy(TempDir,"/tmp");
@@ -211,6 +212,12 @@ int main(argc,argv)
    strcpy(Graphs,"yes");
    strcpy(Ulimit,"20000");
    strcpy(NtlmUserFormat,"domainname+username");
+   strcpy(IndexTree,"file");
+   strcpy(RealtimeTypes,"GET,PUT,CONNECT");
+   strcpy(RealtimeUnauthRec,"ignore");
+   strcpy(SquidguardIgnoreDate,"off");
+   strcpy(DansguardianIgnoreDate,"off");
+   strcpy(DataFileUrl,"ip");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -261,6 +268,12 @@ int main(argc,argv)
    color3=0;
    sarglog=0;
    isalog=0;
+   dotinuser=0;
+   realt=0;
+   realtime_refresh=3;
+   realtime_access_log_lines=1000;
+   cost=0.01;
+   nocost=50000000;
 
    bzero(IncludeUsers, MAXLEN);
    bzero(ExcludeString, MAXLEN);
@@ -271,7 +284,7 @@ int main(argc,argv)
    language_load(language);
    strcpy(Title,text[88]);
 
-   while((ch = getopt(argc, argv, "a:b:c:d:e:f:g:u:l:o:r:s:t:w:hijmnpvxyz")) != -1){
+   while((ch = getopt(argc, argv, "a:b:c:d:e:f:g:u:l:L:o:s:t:w:hijmnprvxyz")) != -1){
       switch(ch)
       {
          case 'a':
@@ -311,6 +324,9 @@ int main(argc,argv)
             strcpy(warq[narq],optarg);
             narq++;
             break;
+         case 'L':
+            strcpy(SquidGuardLogAlternate,optarg);
+            break;
          case 'm':
             debugm++;
             break;
@@ -323,6 +339,9 @@ int main(argc,argv)
          case 'p':
             userip++;
             break;
+         case 'r':
+            realt++;
+            break;
          case 's':
             strcpy(site,optarg);
             break;
@@ -401,6 +420,11 @@ int main(argc,argv)
     
    if(access(ConfigFile, R_OK) == 0)
       getconf(debugm, ConfigFile, AccessLog, debug, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, PasswdFile, TempDir, OutputDir, OutputEmail, Ip2Name, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, UserAgentLog, ExcludeHosts, DateFormat, ExcludeUsers, PerUserLimitFile, PerUserLimit, UserIp, MaxElapsed);
+   
+   if(realt) {
+      realtime();
+      exit(0);
+   }
 
    if(debugz) {
       fprintf(stderr, "SARG: ConfigFile.........= %s\n",ConfigFile);
@@ -440,6 +464,11 @@ int main(argc,argv)
       fprintf(stderr, "SARG:\n");
    }
  
+   if(strcmp(IndexTree,"file") == 0)
+      strcpy(ImageFile,"../images");
+   else
+      strcpy(ImageFile,"../../../images");
+
    dataonly=0;
    if(DataFile[0] != '\0');
       dataonly++;
@@ -493,7 +522,7 @@ int main(argc,argv)
    }
 
    if(ReportType[0] == '\0')
-      strcpy(ReportType,"topsites users_sites sites_users date_time denied auth_failures site_user_time_date");
+      strcpy(ReportType,"topusers topsites users_sites sites_users date_time denied auth_failures site_user_time_date downloads");
 
    if(access(ExcludeUsers, R_OK) == 0) {
       getuexclude(ExcludeUsers,debug);
@@ -551,9 +580,6 @@ int main(argc,argv)
    }
 
    strcpy(tmp2,tmp);
-   strcpy(tmp4,tmp);
-   strcpy(tmp5,tmp);
-   strcpy(tmp6,tmp);
 
    if(strlen(email) > 0) {
       sprintf(wtemp2,"%s/sarg_tmp",tmp2);
@@ -573,6 +599,9 @@ int main(argc,argv)
    
    sprintf(tmp3,"%s/sarg",tmp);
    my_mkdir(tmp3);
+   strcpy(tmp4,tmp3);
+   strcpy(tmp5,tmp3);
+   strcpy(tmp6,tmp3);
    strcat(tmp4,"/denied.log.unsort");
    strcat(tmp5,"/denied.log");
    strcat(tmp6,"/authfail.log.unsort");
@@ -893,7 +922,6 @@ int main(argc,argv)
 
 	   if(!common) {
 	      getword(elap,bufz,' ');
-              bzero(elap, 255);
 	      while(strcmp(elap,"") == 0 && strlen(bufz) > 0)
 	         getword(elap,bufz,' ');
               if(strlen(elap) < 1) continue;
@@ -983,7 +1011,6 @@ int main(argc,argv)
            sprintf(user,"%s.%s",w,wuser);
         }
 
-        dotinuser=0;
 	str=user;
 	for(z1=0; z1<strlen(str); z1++) {
 	   if(isalnum(str[z1]) || ispunct(str[z1])) {
@@ -1020,11 +1047,19 @@ int main(argc,argv)
         if (strchr(url,'/')) {
            getword(w,url,'/');
            getword(w,url,'/');
+          if (!strchr(url,'/')) {
+              totregsx++;
+              continue;
+          }
         }
 
         if(strcmp(LongUrl,"no") == 0) {
            getword(w,url,'/');
            strcpy(url,w);
+           if(strlen(url) > 512 && strstr(url,"%") != 0) {
+              getword(w,url,'%');
+              strcpy(url,w);
+           }
         }
 
         if(!sarglog) {
@@ -1037,8 +1072,10 @@ int main(argc,argv)
 	         strftime(tbuf, 127, "%Y%b%d", t);
               if(strncmp(df,"e",1) == 0)
 	         strftime(tbuf, 127, "%d%b%Y", t);
-              if(strncmp(df,"w",1) == 0)
+              if(strncmp(df,"w",1) == 0) {
+                 strcpy(IndexTree,"file");
 	         strftime(tbuf, 127, "%Y.%U", t);
+              }
 
               strftime(dia, 127, "%d/%m/%Y", t);
               strftime(wdata, 127, "%Y%m%d", t);
@@ -1134,6 +1171,10 @@ int main(argc,argv)
 
         if(puser) {
            sprintf(wuser,":%s:",user);
+           if(dotinuser && strstr(wuser,"_")) {
+               str2=(char *)subs(wuser,"_",".");
+               strcpy(wuser,str2);
+            }
            if(strstr(userfile, wuser) == 0)
               continue;
         }
@@ -1377,14 +1418,14 @@ int main(argc,argv)
          debuga(msg);
       }
    }
- 
-   sort_users_log(tmp, debug);
 
    if(strstr(ReportType,"denied") != 0) {
       sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o '%s' '%s'",tmp,tmp5,tmp4);
       system(csort);
       unlink(tmp4);
    }
+ 
+   sort_users_log(tmp, debug);
 
    report_gen:
    if(strlen(DataFile) > 0)
@@ -1406,6 +1447,15 @@ int main(argc,argv)
    sprintf(csort,"rm -rf %s",tmp);
    system(csort);
 
+   if(excludecode)
+      free(excludecode);
+   if(userfile)
+      free(userfile);
+   if(excludefile)
+      free(excludefile);
+   if(excludeuser)
+      free(excludeuser);
+
    exit(0);
 
 }
