@@ -98,7 +98,11 @@ void report_day(char *user, int *iprel, int *ipuser)
       fputs("</table>\n",fp_ou);
    }
 
-   show_sarg(fp_ou,"../..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_ou, "../../../..");
+   else
+      show_sarg(fp_ou, "../..");
+
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
    sprintf(html,"<tr><th class=\"title\" colspan=2>%s</th></tr>\n",Title);
    fputs(html,fp_ou);
