@@ -79,6 +79,10 @@ void gerarel()
          continue;
       if(strncmp(direntp->d_name,"download.log",12) == 0)
          continue;
+      if(strncmp(direntp->d_name,"denied.log",10) == 0)
+         continue;
+      if(strncmp(direntp->d_name,"authfail.log.unsort",19) == 0)
+         continue;
       sprintf(tmp3,"%s/%s",tmp,direntp->d_name);
       if((fp_in=fopen(tmp3,"r"))==NULL){
          fprintf(stderr, "SARG: (report) %s: %s\n",text[45],tmp);
@@ -243,7 +247,10 @@ void gerarel()
                fputs("</table>\n",fp_tt);
             }
 
-	    show_sarg(fp_tt, "../..");
+            if(strcmp(IndexTree,"date") == 0)
+               show_sarg(fp_tt, "../../../..");
+            else
+               show_sarg(fp_tt, "../..");
 
             sprintf(html,"<tr><th class=\"title\" colspan=\"2\">%s</th></tr>\n",Title);
             fputs(html,fp_tt);
@@ -342,17 +349,16 @@ void gerarel()
    totalger(wdirname, debug, outdir);
 
    if(strlen(email) == 0) {
-      download_report();
+      if(strstr(ReportType,"downloads") != 0)
+         download_report();
 
       if(strlen(DansGuardianConf) > 0) {
          strcpy(wdirname,dirname);
          dansguardian_log();
       }
 
-      if(strlen(SquidGuardConf) > 0) {
-         strcpy(wdirname,dirname);
-         squidguard_log();
-      }
+      strcpy(wdirname,dirname);
+      squidguard_log();
 
       strcpy(wdirname,dirname);
       topuser();
@@ -373,13 +379,12 @@ void gerarel()
       if(strlen(DansGuardianConf) > 0)
          dansguardian_report();
 
-      if(strlen(SquidGuardConf) > 0)
-         squidguard_report();
+      squidguard_report();
 
       if(strstr(ReportType,"users_sites") != 0)
          htmlrel();
 
-      geraindex();
+      make_index();
 
       if(strncmp(SuccessfulMsg,"yes",3) == 0)
          fprintf(stderr, "SARG: %s %s\n",text[47],dirname);
