@@ -101,7 +101,11 @@ void siteuser()
       fputs("</table>\n",fp_ou);
    }
 
-   show_sarg(fp_ou, "..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_ou, "../../..");
+   else
+      show_sarg(fp_ou, "..");
+
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
    sprintf(url,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(url,fp_ou);
@@ -214,6 +218,9 @@ void siteuser()
    fclose(fp_in);
    fclose(fp_ou);
 
+   if(users)
+      free(users);
+
    return;
 
 }
