@@ -28,7 +28,7 @@
 int topuser()
 {
 
-   FILE *fp_in, *fp_ou, *fp_top1, *fp_top2, *fp_top3;
+   FILE *fp_in = NULL, *fp_ou = NULL, *fp_top1 = NULL, *fp_top2 = NULL, *fp_top3 = NULL;
    long long int ttnbytes=0, ttnacc=0, tnacc=0;
    long long int tnbytes=0, ttnelap=0, tnelap=0;
    long long int tnincache=0, tnoucache=0, ttnincache=0, ttnoucache=0;
@@ -43,7 +43,7 @@ int topuser()
    char ipantes[MAXLEN], nameantes[MAXLEN];
    char sfield[10]="2,2";
    char order[255]="-r";
-   char wheader[512];
+   char wheader[512]="";
    char ftime[128];
    int  totuser=0;
    int  topcount=0;
@@ -60,7 +60,7 @@ int topuser()
    strcat(wger,"/geral");
    strcat(top1,"/top");
    strcat(top2,"/top.tmp");
-   strcat(tusr,"/usuarios");
+   strcat(tusr,"/users");
    strcat(top3,"/index.html");
 
    if((fp_in=fopen(wger,"r"))==NULL) {
@@ -154,8 +154,8 @@ int topuser()
    my_lltoa(ttnincache,val4,15);
    my_lltoa(ttnoucache,val5,15);
    sprintf(preg,"TOTAL %s %s %s %s %s\n",val1,val2,val3,val4,val5);
-   fclose(fp_in);
-   fclose(fp_top2);
+   if (fp_in) fclose(fp_in);
+   if (fp_top2) fclose(fp_top2);
 
    strup(TopuserSortField);
    strlow(TopuserSortOrder);
@@ -230,7 +230,10 @@ int topuser()
       fputs("</table>\n",fp_top3);
    }
 
-   show_sarg(fp_top3, "..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_top3, "../../..");
+   else
+      show_sarg(fp_top3, "..");
    fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_top3);
    sprintf(preg,"<tr><th align=\"center\" class=\"title\">%s</th></tr>\n",Title);
    fputs(preg,fp_top3);
@@ -271,17 +274,17 @@ int topuser()
      fputs(preg,fp_top3);
    }
 
-   if(download_count) {
+   if (strstr(ReportType,"downloads") != 0 && download_count) {
       sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"download.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[125],text[55]);
       fputs(preg,fp_top3);
    }
 
-   if(denied_count) {
+   if (strstr(ReportType,"denied") != 0 && denied_count) {
       sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"denied.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[118],text[55]);
       fputs(preg,fp_top3);
    }
 
-   if(authfail_count) {
+   if (strstr(ReportType,"auth_failures") != 0 && authfail_count) {
       sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"authfail.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[117],text[55]);
       fputs(preg,fp_top3);
    }
@@ -293,6 +296,12 @@ int topuser()
    strcpy(preg,"<tr><td></td></tr>\n");
    fputs(preg,fp_top3);
 
+   if (strstr(ReportType,"topuser") == 0) {
+      fputs("</body>\n</html>\n",fp_top3);
+      if (fp_top3)
+         fclose (fp_top3);
+      return;
+   }
    strcpy(val1,text[100]);
    strcpy(val2,text[98]);
    strcpy(val3,text[92]);
@@ -465,9 +474,9 @@ int topuser()
 
       sprintf(val1,"%d",posicao);
 #ifdef HAVE_GD
-      sprintf(val2,"%s<img src=\"../images/graph.png\" border=\"0\" title=\"%s %s\"></a>&nbsp;%s<img src=\"../images/datetime.png\" border=\"0\" title=\"%s %s\">\n",href3,text[126],text[55],href2,ltext110,text[55]);
+      sprintf(val2,"%s<img src=\"%s/graph.png\" border=\"0\" title=\"%s %s\"></a>&nbsp;%s<img src=\"%s/datetime.png\" border=\"0\" title=\"%s %s\">\n",href3,ImageFile,text[126],text[55],href2,ImageFile,ltext110,text[55]);
 #else
-      sprintf(val2,"%s<img src=\"../images/datetime.png\" border=\"0\" title=\"%s %s\">\n",href2,ltext110,text[55]);
+      sprintf(val2,"%s<img src=\"%s/datetime.png\" border=\"0\" title=\"%s %s\">\n",href2,ImageFile,ltext110,text[55]);
 #endif
 
       sprintf(val3,"%3.2f%%",perc);
@@ -534,6 +543,7 @@ int topuser()
       if(dotinuser && strstr(name,"_")) {
          str2=(char *)subs(name,"_",".");
          strcpy(name,str2);
+         free(str2);
       }
 
       sprintf(preg,"<tr><td %s>%s</td><td %s>%s</td><td %s>%s%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s<td %s>%s</td></tr>\n",hbc1,val1,hbc2,val2,hbc2,href,name,hbc3,wwork1,hbc4,wwork2,hbc5,val3,hbc6,val4,hbc7,val5,hbc8,val6,hbc9,wwork3,hbc10,val7);
