@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -54,7 +54,7 @@ void totaliza_day(const char *tmp, char *user, int indexonly)
    sprintf(arqout,"%s/%s.day",tmp,user);
    sprintf(sortout,"%s/%s.sort",tmp,user);
 
-   sprintf(csort,"sort -k 1,1 -k 2,2 -o %s %s",sortout,wdirname);
+   sprintf(csort,"sort -k 1,1 -k 2,2 -o '%s' '%s'",sortout,wdirname);
    system(csort);
 
    unlink(wdirname);
