@@ -160,7 +160,10 @@ void useragent()
       fputs("</table>\n",fp_ht);
    }
 
-   show_sarg(fp_ht,"..");
+   if(strcmp(IndexTree,"date") == 0)
+      show_sarg(fp_ht, "../../..");
+   else
+      show_sarg(fp_ht,"..");
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ht);
    sprintf(html,"<tr><th align=center colspan=2><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,text[105]);
    fputs(html,fp_ht);
