@@ -308,6 +308,20 @@ void conv_month_name(char *month)
 }
 
 
+void name_month(char *month)
+{
+   int  x, z=atoi(month)-1;
+   char m[255];
+   char w[20];
+
+   strcpy(m,text[133]);
+
+   for(x=0; x<z; x++)
+      getword(w,m,',');
+   getword(month,m,',');
+}
+
+
 void fixper(char *tbuf, char *periodo, char *duntil)
 {
 
@@ -545,7 +559,7 @@ void obtuser(char *dirname, char *name, char *tuser)
    FILE *fp_in;
    char wdir[MAXLEN];
 
-   sprintf(wdir,"%s%s/usuarios",dirname,name);
+   sprintf(wdir,"%s%s/users",dirname,name);
    if((fp_in=fopen(wdir,"r"))==NULL){    
       tuser[0]='\0';
       return;
@@ -641,7 +655,56 @@ void vrfydir(char *dir, char *per1, char *addr, char *site, char *us, char *form
    DIR *dirp;
    struct dirent *direntp;
 
-   sprintf(wdir,"%s",dir);
+   if(strcmp(IndexTree,"date") == 0) {
+      bzero(y1,5);
+      bzero(y2,5);
+      bzero(d1,3);
+      bzero(d2,3);
+      bzero(m1,4);
+      bzero(m2,4);
+      if(strncmp(df,"u",1) == 0) {
+         strncpy(y1,periodo,4);
+         strncpy(y2,periodo+10,4);
+         strncpy(m1,periodo+4,3);
+         strncpy(m2,periodo+14,3);
+         strncpy(d1,periodo+7,2);
+         strncpy(d2,periodo+17,2);
+      } else if(strncmp(df,"e",1) == 0) {
+         strncpy(d1,periodo+0,2);
+         strncpy(d2,periodo+10,2);
+         strncpy(m1,periodo+2,3);
+         strncpy(m2,periodo+12,3);
+         strncpy(y1,periodo+5,4);
+         strncpy(y2,periodo+15,4);
+      }
+      conv_month(m1);
+      conv_month(m2);
+
+      sprintf(wdir,"%s%s",outdir,y1);
+      if(strcmp(y1,y2) != 0) {
+         strncat(wdir,"-",1);
+         strncat(wdir,y2,strlen(y2));
+      }
+      if(access(wdir, R_OK) != 0)
+         my_mkdir(wdir);
+   
+      strncat(wdir,"/",1);
+      strncat(wdir,m1,strlen(m1));
+      if(strcmp(m1,m2) != 0) {
+         strncat(wdir,"-",1);
+         strncat(wdir,m2,strlen(m2));
+      }
+      if(access(wdir, R_OK) != 0)
+         my_mkdir(wdir);
+   
+      strncat(wdir,"/",1);
+      strncat(wdir,d1,strlen(d1));
+      if(strcmp(d1,d2) != 0) {
+         strncat(wdir,"-",1);
+         strncat(wdir,d2,strlen(d2));
+      }
+   } else
+      sprintf(wdir,"%s",dir);
 
    if(strlen(us) > 0) {
       strcat(wdir,"-");
@@ -659,33 +722,61 @@ void vrfydir(char *dir, char *per1, char *addr, char *site, char *us, char *form
    if(strcmp(dirname,wdir) != 0)
       strcpy(dirname,wdir);
 
-   strcpy(dirname2,dirname);
+   if(strcmp(IndexTree,"date") != 0) {
+      strcpy(dirname2,dirname);
+      if(strcmp(OverwriteReport,"no") == 0) {
+         while(num) {
+            if(access(wdir,R_OK) == 0) {
+               sprintf(wdir,"%s.%d",dirname,num);
+               sprintf(per2,"%s.%d",per1,num);
+               num++;
+               count++;
+            } else
+               break;
+         }
 
-   if(strcmp(OverwriteReport,"no") == 0) {
-      while(num) {
-         if(access(wdir,R_OK) == 0) {
-            sprintf(wdir,"%s.%d",dirname,num);
-            sprintf(per2,"%s.%d",per1,num);
-            num++;
-            count++;
-         } else
-            break;
-      }
-
-      if(count > 0) {
-         if(debug)
-            fprintf(stderr, "SARG: %s: %s %s %s\n",text[51],dirname2,text[52],wdir);
-         rename(dirname2,wdir);
+         if(count > 0) {
+            if(debug)
+               fprintf(stderr, "SARG: %s: %s %s %s\n",text[51],dirname2,text[52],wdir);
+            rename(dirname2,wdir);
+         }
+      } else {
+         if(access(dir,R_OK) == 0) {
+            sprintf(csort,"rm -r %s",dir);
+            system(csort);
+         }
       }
+      my_mkdir(dirname);
    } else {
-      if(access(dir,R_OK) == 0) {
-         sprintf(csort,"rm -r %s",dir);
-         system(csort);
+      strcpy(dirname2,wdir);
+      if(strcmp(OverwriteReport,"no") == 0) {
+         while(num) {
+            if(access(wdir,R_OK) == 0) {
+               sprintf(wdir,"%s.%d",dirname2,num);
+               sprintf(per2,"%s.%d",per1,num);
+               num++;
+               count++;
+            } else
+               break;
+         }
+   
+         if(count > 0) {
+            if(debug)
+               fprintf(stderr, "SARG: %s: %s %s %s\n",text[51],dirname2,text[52],wdir);
+            rename(dirname2,wdir);
+            strcpy(dirname2,wdir);
+         }
+      } else {
+         if(access(wdir,R_OK) == 0) {
+            sprintf(csort,"rm -r %s",wdir);
+            system(csort);
+         }
       }
+   
+      if(access(wdir, R_OK) != 0)
+         my_mkdir(wdir);
    }
 
-   my_mkdir(dirname);
-
    strcpy(dirname2,wdir);
    sprintf(images,"%simages",outdir);
    mkdir(images,0755);
@@ -874,7 +965,7 @@ char *subs(char *str, char *from, char *to)
    if(strstr(str,from) == 0)
       return (char *) str;
 
-    ss = strlen(str); st = strlen(to);
+    ss = strlen(str); st = strlen(to) + 10;
     ret = (char *) malloc(ss + st);
     bzero(ret,ss+st);
 
@@ -1076,7 +1167,7 @@ void show_sarg(FILE *fp_ou, char *ind)
 {
    if(strcmp(ShowSargLogo,"yes") == 0) {
       fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
-      sprintf(html,"<tr><th class=\"logo\"><a href=\"http://www.sarg-squid.org\"><img src=\"%s/images/sarg.png\" border=\"0\" align=\"absmiddle\" title=\"SARG, Squid Analysis Report Generator. Logo by Osamu Matsuzaki\"></a>&nbsp;<font class=\"logo\">Squid Analysis Report Generator</font></th></tr>\n",ind,Title);
+      sprintf(html,"<tr><th class=\"logo\"><a href=\"http://sarg.sourceforge.net\"><img src=\"%s/images/sarg.png\" border=\"0\" align=\"absmiddle\" title=\"SARG, Squid Analysis Report Generator. Logo by Osamu Matsuzaki\"></a>&nbsp;<font class=\"logo\">Squid Analysis Report Generator</font></th></tr>\n",ind,Title);
       fputs(html,fp_ou);
       sprintf(html,"<tr><th class=\"title\">&nbsp</th></tr>\n",Title);
       fputs(html,fp_ou);
@@ -1084,6 +1175,61 @@ void show_sarg(FILE *fp_ou, char *ind)
    }
 }
 
+get_size(char *path, char *file)
+{
+   FILE *fp;
+   char response[255];
+
+   sprintf(cmd,"du -skh %s%s",path,file);
+   fp = popen(cmd, "r");
+   fgets(response, 255, fp);
+   getword(val5,response,'\t');
+   pclose(fp);
+
+   return (val5);
+}
+
+
+void write_html_header(FILE *fp_ou, char * ind)
+{
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
+   fputs("<html>\n",fp_ou);
+   fputs("<head>\n",fp_ou);
+   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
+   fputs(html,fp_ou);
+   fputs("</head>\n",fp_ou);
+   css(fp_ou);
+   sprintf(buf,"<body style=\"font-family:%s;font-size:%s;background-color:%s;background-image:url(%s)\">\n",FontFace,TitleFontSize,BgColor,BgImage);
+   fputs(buf,fp_ou);
+   sprintf(buf,"<center><table cellpadding=\"0\" cellspacing=\"0\">\n");
+   fputs(buf,fp_ou);
+   if(strlen(LogoImage) > 0) {
+      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
+      sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
+      fputs(html,fp_ou);
+      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
+      fputs("</table>\n",fp_ou);
+   }
+   show_sarg(fp_ou, ind);
+   sprintf(html,"<tr><th class=\"title\">%s</th></tr>\n",Title);
+   fputs(html,fp_ou);
+   fputs("</table></center>\n",fp_ou);
+   fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
+   fputs("<tr><td></td><td></td></tr>\n",fp_ou);
+
+}
+
+
+void write_html_trailer(FILE *fp_ou)
+{
+   fputs("</table></center>\n",fp_ou);
+   zdate(ftime, DateFormat);
+   show_info(fp_ou);
+   fputs("</body>\n</html>\n",fp_ou);
+}
+
+
 char url_module(char *url, char *w2)
 {
    int x, y;
